@@ -34,7 +34,7 @@ public:
     ~ContactEditorMainWindow();
 
 protected:
-    void closeEvent(QCloseEvent *) Q_DECL_OVERRIDE;
+    void closeEvent(QCloseEvent *) override;
 
 private Q_SLOTS:
     void slotNewTheme();
